@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Dict, Type
+from typing import TYPE_CHECKING, Dict, Iterable, Type, Union
 from urllib.parse import urlparse
 from uuid import uuid4
 
@@ -29,15 +29,21 @@ class LimiterMixin(MixinBase):
 
     def __init__(
         self,
-        *rates: RequestRate,
+        rates: Union[RequestRate, Iterable[RequestRate]],
         bucket_class: Type[AbstractBucket] = MemoryQueueBucket,
         bucket_kwargs: Dict = None,
         per_host: bool = False,
         **kwargs,
     ):
+        self._default_bucket = str(uuid4())
+        bucket_kwargs = bucket_kwargs or {}
+        bucket_kwargs.setdefault('bucket_name', self._default_bucket)
+
+        if not isinstance(rates, Iterable):
+            rates = [rates]
+
         self.limiter = Limiter(*rates, bucket_class=bucket_class, bucket_kwargs=bucket_kwargs)
         self.per_host = per_host
-        self._default_bucket = str(uuid4())
         super().__init__(**kwargs)
 
     def bucket_name(self, request):
@@ -51,8 +57,13 @@ class LimiterMixin(MixinBase):
 
 
 class LimiterSession(LimiterMixin, Session):  # type: ignore  # false positive due to MixinBase
-    """Session that adds rate-limiting"""
+    """`Session <https://docs.python-requests.org/en/master/user/advanced/#session-objects>`_
+    that adds rate-limiting behavior to requests.
+    """
 
 
 class LimiterAdapter(LimiterMixin, HTTPAdapter):
-    """Transport adapter that adds rate-limiting"""
+    """`Transport adapter
+    <https://docs.python-requests.org/en/master/user/advanced/#transport-adapters>`_
+    that adds rate-limiting behavior to requests.
+    """
